@@ -4,10 +4,9 @@ use strict;
 use warnings;
 use utf8;
 
-#base 'Mojo::Command';
 use Mojo::Base 'Mojolicious::Command';
 
-our $VERSION = 0.994;
+our $VERSION = 0.995;
 
 use File::Find;
 use Getopt::Long;
@@ -56,7 +55,7 @@ sub run {
         "behavior|b:s{1,1}" => \$behavior,
         'verbose|v:1'        => \$verbose,
     );
-    push @templates, $_[0] if (defined $_[0]);
+    push @templates, $ARGV[0] if (defined $ARGV[0]);
 
     my $handler = $app->renderer->default_handler;
 
@@ -76,7 +75,7 @@ sub run {
     if ($language ne 'Skeleton' && -e $lexem_file) {
         if (lc $behavior eq 'save') {
             %oldlex = eval {
-                require "$app_klass/I18N/$language.pm";
+                require "$app_class/I18N/$language.pm";
                 no strict 'refs';
                 %{*{"${app_klass}::I18N::${language}::Lexicon"}};
             };
